using System;
using System.Reflection;
using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;

[assembly: AssemblyTitle("Smuxi - Campfire support")]
[assembly: AssemblyCopyright("2012-2013 © Carlos Martín Nieto <cmn@dwim.me>")]

[assembly: AssemblyDelaySign(false)]
[assembly: AssemblyKeyFile("")]

[assembly: CLSCompliant(true)]
[assembly: ComVisible(false)]
